# Contributors
Contributors to shipgrav are listed and described using the [Contributor Role Taxonomoy (CRediT)](https://credit.niso.org/)

## Hannah F. Mark
- Conceptualization
- Data curation
- Software
- Visualization
- Writing -- original draft (JOSS)
- Writing -- review and editing (JOSS)

## Masako Tominaga
- Conceptualization
- Funding acquisition
- Supervision
- Validation
- Writing -- review and editing (JOSS)

## Jasmine Zhu
- Software

## Maurice Tivey
- Funding acquisition
- Writing -- review and editing (JOSS)

## Daniel Aliod
- Software
